**********************
``hvpy`` Documentation
**********************

``hvpy`` is a Python package which provides a high-level interface the `helioviewer.org <https://helioviewer.org>`__ `API <https://api.helioviewer.org/docs/v2/>`__.

.. toctree::
   :maxdepth: 2

   installation
   guide
   api
   dev_guide

Contribute to ``hvpy``
----------------------

Reporting Issues or Requesting Features
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

If you have found a bug in ``hvpy`` please report it.
The preferred way to report issues is to create an issue on the ``hvpy`` `GitHub Issue page <https://github.com/Helioviewer-Project/python-api/issues>`__.

Contribute code or documentation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

People who wish to contribute to this package should fork the `GitHub repository <https://github.com/Helioviewer-Project/python-api>`__.

You need to install the development version of the package in order to make and test changes.
See the :ref:`obtaining_the_source` section for details.

You may also want to familiarize yourself with the :ref:`dev_guide` for ``hvpy``.

Changelog
---------

The changelog for ``hvpy`` is available on the `GitHub releases page <https://github.com/Helioviewer-Project/python-api/releases>`__.
